@@ -38,13 +38,3 @@ class Image_reading_class(object):
     def close(self):
         self.image.close()
 
-
-class Image(object):
-
-    def __init__(self, ImageWidth: int, ImageHeight: int, ImageBitDepth: int,
-                                                        ImageChannelsAmount: int, ImageData: List[List[List[int]]]):
-        self.width = ImageWidth
-        self.height = ImageHeight
-        self.bit_depth = ImageBitDepth
-        self.channels_amount = ImageChannelsAmount
-        self.data = ImageData
\ No newline at end of file
