@@ -1,5 +1,5 @@
 from typing import List, Tuple
-from Image_reader import Image, Image_reading_class
+from Image_reader import Image_reading_class
 from JFIF_Decoder_Algorithms import do_InverseDCT
 
 ITERATION_LIMIT = 100
@@ -261,8 +261,7 @@ def decode(image: Image_reading_class, xff: bool = False, marker_name: str = '')
 
             elif marker_name == 217:  # EOI (End Of Image)
                 image.close()
-                img = Image(img_width, img_height, img_bd, img_cc, img_data)
-                return img
+                return img_data
 
 
             elif marker_name == 254: #COMMENTARY MARKER
